@@ -5,5 +5,5 @@ from regrex.transform import Transformer
 from regrex.dataset import LoadData, SaveData, TestTrainSplit
 from regrex.statistics import MeanSquaredError, abstract, arraylog, square
 from regrex.validation import Difference, ScoreValidation
-from regrex.log import log, error, nnewline
+from regrex.log import log, error, newline
 from regrex.SingleLineFunction import SLF
\ No newline at end of file
