@@ -1,10 +1,8 @@
 import sys
 
-def Difference(certainval, uncertainval):
-    if certainval > uncertainval:
-        return certainval - uncertainval
-    else:
-        return uncertainval - certainval    
+def Difference(mse):
+    return float(mse)
+    
 def ScoreValidation(modelscore):
     if modelscore > 0.100:
         print("\n\n")
